@@ -61,6 +61,10 @@ testcase "adding member to a project" '
         --user-id "$USER_ID" --access-level 40 >/dev/null 2>&1
 '
 
+testcase "listing user memberships" '
+    GITLAB user-membership list --user-id "$USER_ID" >/dev/null 2>&1
+'
+
 testcase "file creation" '
     GITLAB project-file create --project-id "$PROJECT_ID" \
         --file-path README --branch master --content "CONTENT" \
@@ -100,6 +104,15 @@ testcase "merge request validation" '
         --iid "$MR_ID" >/dev/null 2>&1
 '
 
+# Test revert commit
+COMMITS=$(GITLAB -v project-commit list --project-id "${PROJECT_ID}")
+COMMIT_ID=$(pecho "${COMMITS}" | grep -m1 '^id:' | cut -d' ' -f2)
+
+testcase "revert commit" '
+    GITLAB project-commit revert --project-id "$PROJECT_ID" \
+        --id "$COMMIT_ID" --branch master
+'
+
 # Test project labels
 testcase "create project label" '
     OUTPUT=$(GITLAB -v project-label create --project-id $PROJECT_ID \
